@@ -18,6 +18,9 @@ elif [ -n "$TRAVIS_PYTHON_VERSION" ]; then
     searchstring="$(echo py$TRAVIS_PYTHON_VERSION | sed -e 's/pypypy/pypy/g' -e 's/-dev//g')"
 elif [ -n "$AZURE_PYTHON_VERSION" ]; then
     searchstring="$(echo py$AZURE_PYTHON_VERSION | sed -e 's/pypypy/pypy/g' -e 's/-dev//g')"
+    if [ "$searchstring" = pypy2 ]; then
+        searchstring=pypy
+    fi
 fi
 
 exec $TOXPATH -e $($TOXPATH -l | grep "$searchstring" | tr '\n' ',') -- "${@:2}"
