@@ -1,11 +1,9 @@
 import copy
 import random
 import sys
-import weakref
 
 from datetime import datetime
 from contextlib import contextmanager
-from warnings import warn
 
 from sentry_sdk._compat import with_metaclass
 from sentry_sdk.scope import Scope
@@ -46,8 +44,7 @@ else:
         return x
 
 
-_local = ContextVar("sentry_current_hub")  # type: ignore
-_initial_client = None  # type: Optional[weakref.ReferenceType[Client]]
+_local = ContextVar("sentry_current_hub")
 
 
 def _should_send_default_pii():
@@ -80,12 +77,9 @@ def _init(*args, **kwargs):
 
     This takes the same arguments as the client constructor.
     """
-    global _initial_client
     client = Client(*args, **kwargs)  # type: ignore
     Hub.current.bind_client(client)
     rv = _InitGuard(client)
-    if client is not None:
-        _initial_client = weakref.ref(client)
     return rv
 
 
@@ -112,7 +106,7 @@ else:
 
 class HubMeta(type):
     @property
-    def current(self):
+    def current(cls):
         # type: () -> Hub
         """Returns the current instance of the hub."""
         rv = _local.get(None)
@@ -122,7 +116,7 @@ class HubMeta(type):
         return rv
 
     @property
-    def main(self):
+    def main(cls):
         # type: () -> Hub
         """Returns the main instance of the hub."""
         return GLOBAL_HUB
@@ -262,32 +256,18 @@ class Hub(with_metaclass(HubMeta)):  # type: ignore
             if rv is not None:
                 return rv
 
-        if _initial_client is not None:
-            initial_client = _initial_client()
-        else:
-            initial_client = None
-
-        if (
-            initial_client is not None
-            and initial_client is not client
-            and initial_client.integrations.get(integration_name) is not None
-        ):
-            warning = (
-                "Integration %r attempted to run but it was only "
-                "enabled on init() but not the client that "
-                "was bound to the current flow.  Earlier versions of "
-                "the SDK would consider these integrations enabled but "
-                "this is no longer the case." % (name_or_class,)
-            )
-            warn(Warning(warning), stacklevel=3)
-            logger.warning(warning)
-
     @property
     def client(self):
         # type: () -> Optional[Client]
         """Returns the current client on the hub."""
         return self._stack[-1][0]
 
+    @property
+    def scope(self):
+        # type: () -> Scope
+        """Returns the current scope on the hub."""
+        return self._stack[-1][1]
+
     def last_event_id(self):
         # type: () -> Optional[str]
         """Returns the last event ID."""
@@ -347,10 +327,10 @@ class Hub(with_metaclass(HubMeta)):  # type: ignore
         client = self.client
         if client is None:
             return None
-        if error is None:
-            exc_info = sys.exc_info()
-        else:
+        if error is not None:
             exc_info = exc_info_from_error(error)
+        else:
+            exc_info = sys.exc_info()
 
         event, hint = event_from_exception(exc_info, client_options=client.options)
         try:
@@ -370,7 +350,7 @@ class Hub(with_metaclass(HubMeta)):  # type: ignore
 
         These exceptions do not end up in Sentry and are just logged instead.
         """
-        logger.error("Internal error in sentry_sdk", exc_info=exc_info)  # type: ignore
+        logger.error("Internal error in sentry_sdk", exc_info=exc_info)
 
     def add_breadcrumb(
         self,
@@ -440,8 +420,9 @@ class Hub(with_metaclass(HubMeta)):  # type: ignore
         kwargs.setdefault("hub", self)
 
         if span is None:
-            if scope.span is not None:
-                span = scope.span.new_span(**kwargs)
+            span = scope.span
+            if span is not None:
+                span = span.new_span(**kwargs)
             else:
                 span = Span(**kwargs)
 
@@ -496,8 +477,6 @@ class Hub(with_metaclass(HubMeta)):  # type: ignore
 
         return _ScopeManager(self)
 
-    scope = push_scope
-
     def pop_scope_unsafe(self):
         # type: () -> Tuple[Optional[Client], Scope]
         """
@@ -570,7 +549,9 @@ class Hub(with_metaclass(HubMeta)):  # type: ignore
         # type: () -> Generator[Tuple[str, str], None, None]
         # TODO: Document
         client, scope = self._stack[-1]
-        if scope._span is None:
+        span = scope.span
+
+        if span is None:
             return
 
         propagate_traces = client and client.options["propagate_traces"]
@@ -578,9 +559,9 @@ class Hub(with_metaclass(HubMeta)):  # type: ignore
             return
 
         if client and client.options["traceparent_v2"]:
-            traceparent = scope._span.to_traceparent()
+            traceparent = span.to_traceparent()
         else:
-            traceparent = scope._span.to_legacy_traceparent()
+            traceparent = span.to_legacy_traceparent()
 
         yield "sentry-trace", traceparent
 
