@@ -15,10 +15,19 @@ from sentry_sdk._types import MYPY
 
 if MYPY:
     from typing import Any
+    from typing import TypeVar
+    from typing import Callable
+    from typing import Optional
+
+    from sentry_sdk._types import EventProcessor, Event, Hint
+
+    F = TypeVar("F", bound=Callable[..., Any])
 
 
 def _wrap_handler(handler):
+    # type: (F) -> F
     def sentry_handler(event, context, *args, **kwargs):
+        # type: (Any, Any, *Any, **Any) -> Any
         hub = Hub.current
         integration = hub.get_integration(AwsLambdaIntegration)
         if integration is None:
@@ -45,10 +54,11 @@ def _wrap_handler(handler):
                 hub.capture_event(event, hint=hint)
                 reraise(*exc_info)
 
-    return sentry_handler
+    return sentry_handler  # type: ignore
 
 
 def _drain_queue():
+    # type: () -> None
     with capture_internal_exceptions():
         hub = Hub.current
         integration = hub.get_integration(AwsLambdaIntegration)
@@ -87,6 +97,7 @@ class AwsLambdaIntegration(Integration):
             old_handle_event_request = lambda_bootstrap.handle_event_request
 
             def sentry_handle_event_request(request_handler, *args, **kwargs):
+                # type: (Any, *Any, **Any) -> Any
                 request_handler = _wrap_handler(request_handler)
                 return old_handle_event_request(request_handler, *args, **kwargs)
 
@@ -95,6 +106,7 @@ class AwsLambdaIntegration(Integration):
             old_handle_http_request = lambda_bootstrap.handle_http_request
 
             def sentry_handle_http_request(request_handler, *args, **kwargs):
+                # type: (Any, *Any, **Any) -> Any
                 request_handler = _wrap_handler(request_handler)
                 return old_handle_http_request(request_handler, *args, **kwargs)
 
@@ -106,6 +118,7 @@ class AwsLambdaIntegration(Integration):
             old_to_json = lambda_bootstrap.to_json
 
             def sentry_to_json(*args, **kwargs):
+                # type: (*Any, **Any) -> Any
                 _drain_queue()
                 return old_to_json(*args, **kwargs)
 
@@ -127,11 +140,13 @@ class AwsLambdaIntegration(Integration):
             # even when the SDK is initialized inside of the handler
 
             def _wrap_post_function(f):
+                # type: (F) -> F
                 def inner(*args, **kwargs):
+                    # type: (*Any, **Any) -> Any
                     _drain_queue()
                     return f(*args, **kwargs)
 
-                return inner
+                return inner  # type: ignore
 
             lambda_bootstrap.LambdaRuntimeClient.post_invocation_result = _wrap_post_function(
                 lambda_bootstrap.LambdaRuntimeClient.post_invocation_result
@@ -142,7 +157,9 @@ class AwsLambdaIntegration(Integration):
 
 
 def _make_request_event_processor(aws_event, aws_context):
+    # type: (Any, Any) -> EventProcessor
     def event_processor(event, hint):
+        # type: (Event, Hint) -> Optional[Event]
         extra = event.setdefault("extra", {})
         extra["lambda"] = {
             "remaining_time_in_millis": aws_context.get_remaining_time_in_millis(),
@@ -152,7 +169,7 @@ def _make_request_event_processor(aws_event, aws_context):
             "aws_request_id": aws_context.aws_request_id,
         }
 
-        request = event.setdefault("request", {})
+        request = event.get("request", {})
 
         if "httpMethod" in aws_event:
             request["method"] = aws_event["httpMethod"]
@@ -181,12 +198,15 @@ def _make_request_event_processor(aws_event, aws_context):
             if ip is not None:
                 user_info["ip_address"] = ip
 
+        event["request"] = request
+
         return event
 
     return event_processor
 
 
 def _get_url(event, context):
+    # type: (Any, Any) -> str
     path = event.get("path", None)
     headers = event.get("headers", {})
     host = headers.get("Host", None)
