@@ -1,6 +1,7 @@
 import os
 import subprocess
 import json
+import uuid
 
 import pytest
 
@@ -10,6 +11,7 @@ import eventlet
 import sentry_sdk
 from sentry_sdk._compat import reraise, string_types, iteritems
 from sentry_sdk.transport import Transport
+from sentry_sdk.utils import capture_internal_exceptions
 
 from tests import _warning_recorder, _warning_recorder_mgr
 
@@ -67,6 +69,11 @@ def _capture_internal_warnings():
         except NameError:
             pass
 
+        if "sentry_sdk" not in str(warning.filename) and "sentry-sdk" not in str(
+            warning.filename
+        ):
+            continue
+
         # pytest-django
         if "getfuncargvalue" in str(warning.message):
             continue
@@ -118,8 +125,9 @@ def monkeypatch_test_transport(monkeypatch, semaphore_normalize):
                 if isinstance(value, dict):
                     check_string_keys(value)
 
-        check_string_keys(event)
-        semaphore_normalize(event)
+        with capture_internal_exceptions():
+            check_string_keys(event)
+            semaphore_normalize(event)
 
     def inner(client):
         monkeypatch.setattr(client, "transport", TestTransport(check_event))
@@ -156,13 +164,14 @@ def semaphore_normalize(tmpdir):
         # Disable subprocess integration
         with sentry_sdk.Hub(None):
             # not dealing with the subprocess API right now
-            file = tmpdir.join("event")
+            file = tmpdir.join("event-{}".format(uuid.uuid4().hex))
             file.write(json.dumps(dict(event)))
-            output = json.loads(
-                subprocess.check_output(
-                    [SEMAPHORE, "process-event"], stdin=file.open()
-                ).decode("utf-8")
-            )
+            with file.open() as f:
+                output = json.loads(
+                    subprocess.check_output(
+                        [SEMAPHORE, "process-event"], stdin=f
+                    ).decode("utf-8")
+                )
             _no_errors_in_semaphore_response(output)
             output.pop("_meta", None)
             return output
@@ -171,14 +180,21 @@ def semaphore_normalize(tmpdir):
 
 
 @pytest.fixture
-def sentry_init(monkeypatch_test_transport):
+def sentry_init(monkeypatch_test_transport, request):
     def inner(*a, **kw):
         hub = sentry_sdk.Hub.current
         client = sentry_sdk.Client(*a, **kw)
         hub.bind_client(client)
         monkeypatch_test_transport(sentry_sdk.Hub.current.client)
 
-    return inner
+    if request.node.get_closest_marker("forked"):
+        # Do not run isolation if the test is already running in
+        # ultimate isolation (seems to be required for celery tests that
+        # fork)
+        yield inner
+    else:
+        with sentry_sdk.Hub(None):
+            yield inner
 
 
 class TestTransport(Transport):
@@ -244,7 +260,11 @@ class EventStreamReader(object):
 
 
 # scope=session ensures that fixture is run earlier
-@pytest.fixture(scope="session", params=[None, "eventlet", "gevent"])
+@pytest.fixture(
+    scope="session",
+    params=[None, "eventlet", "gevent"],
+    ids=("threads", "eventlet", "greenlet"),
+)
 def maybe_monkeypatched_threading(request):
     if request.param == "eventlet":
         try:
