@@ -40,10 +40,7 @@ def test_crumb_capture(sentry_init, capture_events):
 
 def test_crumb_capture_hint(sentry_init, capture_events):
     def before_breadcrumb(crumb, hint):
-        if "httplib_response" in hint:
-            con = hint["httplib_response"].getheader("Connection")
-            assert con.lower() == "close"
-            crumb["data"]["extra"] = "foo"
+        crumb["data"]["extra"] = "foo"
         return crumb
 
     sentry_init(integrations=[StdlibIntegration()], before_breadcrumb=before_breadcrumb)
