@@ -1,3 +1,4 @@
+import pytest
 import random
 import time
 
@@ -5,6 +6,7 @@ import time
 from sentry_sdk.utils import _is_threading_local_monkey_patched
 
 
+@pytest.mark.forked
 def test_thread_local_is_patched(maybe_monkeypatched_threading):
     if maybe_monkeypatched_threading is None:
         assert not _is_threading_local_monkey_patched()
@@ -12,6 +14,7 @@ def test_thread_local_is_patched(maybe_monkeypatched_threading):
         assert _is_threading_local_monkey_patched()
 
 
+@pytest.mark.forked
 def test_leaks(maybe_monkeypatched_threading):
     import threading
 
